@@ -86,8 +86,8 @@ impl BrowserState {
         self.tree.root()
     }
 
-    pub fn page_height(screen: Screen) -> i32 {
-        i32::from(screen.height) - 2
+    pub fn page_height(screen: Screen) -> usize {
+        screen.height as usize - 2 // br shouldn't be displayed when the screen is smaller
     }
 
     /// return a reference to the currently displayed tree, which
@@ -207,7 +207,7 @@ impl PanelState for BrowserState {
         let tree = self.displayed_tree();
         let mut selection = tree.selected_line().as_selection();
         selection.line = tree.options.pattern.pattern
-            .get_match_line_count(&selection.path)
+            .get_match_line_count(selection.path)
             .unwrap_or(0);
         Some(selection)
     }
@@ -243,7 +243,7 @@ impl PanelState for BrowserState {
         _screen: Screen,
         _con: &AppContext,
     ) -> Result<CmdResult, ProgramError> {
-        self.displayed_tree_mut().try_select_y(y as i32);
+        self.displayed_tree_mut().try_select_y(y as usize);
         Ok(CmdResult::Keep)
     }
 
@@ -356,32 +356,32 @@ impl PanelState for BrowserState {
                 CmdResult::Keep
             }
             Internal::previous_match => {
-                self.displayed_tree_mut().try_select_previous_match();
+                self.displayed_tree_mut().try_select_previous_match(page_height);
                 CmdResult::Keep
             }
             Internal::next_match => {
-                self.displayed_tree_mut().try_select_next_match();
+                self.displayed_tree_mut().try_select_next_match(page_height);
                 CmdResult::Keep
             }
             Internal::previous_same_depth => {
-                self.displayed_tree_mut().try_select_previous_same_depth();
+                self.displayed_tree_mut().try_select_previous_same_depth(page_height);
                 CmdResult::Keep
             }
             Internal::next_same_depth => {
-                self.displayed_tree_mut().try_select_next_same_depth();
+                self.displayed_tree_mut().try_select_next_same_depth(page_height);
                 CmdResult::Keep
             }
             Internal::page_down => {
                 let tree = self.displayed_tree_mut();
-                if page_height < tree.lines.len() as i32 {
-                    tree.try_scroll(page_height, page_height);
+                if !tree.try_scroll(page_height as i32, page_height) {
+                    tree.try_select_last(page_height);
                 }
                 CmdResult::Keep
             }
             Internal::page_up => {
                 let tree = self.displayed_tree_mut();
-                if page_height < tree.lines.len() as i32 {
-                    tree.try_scroll(-page_height, page_height);
+                if !tree.try_scroll(page_height as i32 * -1, page_height) {
+                    tree.try_select_first();
                 }
                 CmdResult::Keep
             }
@@ -428,7 +428,7 @@ impl PanelState for BrowserState {
             }
             Internal::parent => self.go_to_parent(screen, con, bang),
             Internal::print_tree => {
-                print::print_tree(&self.displayed_tree(), cc.app.screen, &cc.app.panel_skin, con)?
+                print::print_tree(self.displayed_tree(), cc.app.screen, cc.app.panel_skin, con)?
             }
             Internal::root_up => {
                 let tree = self.displayed_tree();
@@ -587,8 +587,8 @@ impl PanelState for BrowserState {
         disc: &DisplayContext,
     ) -> Result<(), ProgramError> {
         let dp = DisplayableTree {
-            app_state: Some(&disc.app_state),
-            tree: &self.displayed_tree(),
+            app_state: Some(disc.app_state),
+            tree: self.displayed_tree(),
             skin: &disc.panel_skin.styles,
             ext_colors: &disc.con.ext_colors,
             area: disc.state_area.clone(),
